@@ -1,3 +1,4 @@
+from __future__ import unicode_literals
 from decimal import Decimal
 from unittest import TestCase
 
@@ -17,8 +18,8 @@ JWT_DATA = {
     'iss': 'Google',
     'aud': SELLER_ID,
     'typ': 'google/payments/inapp/item/v1/postback/buy',
-    'iat': '1309988959',
-    'exp': '1409988959',
+    'iat': 1309988959,
+    'exp': 1409988959,
     'request': {
         'name': 'Test Order #12',
         'price': '22.50',
